package com.ff.common.mapper;

import java.util.List;
import com.ff.common.domain.TenantGameQuota;

/**
 * 租户游戏配额Mapper接口
 * 
 * @author shi
 * @date 2025-02-12
 */
public interface TenantGameQuotaMapper 
{
    /**
     * 查询租户游戏配额
     * 
     * @param id 租户游戏配额主键
     * @return 租户游戏配额
     */
     TenantGameQuota selectTenantGameQuotaById(Long id);


     /**
     * 查询租户游戏配额
     *
     * @param tenantKey 租户游戏配额主键
     * @return 租户游戏配额
     */
     TenantGameQuota selectTenantGameQuotaByTenantKey(String tenantKey);

    /**
     * 查询租户游戏配额列表
     * 
     * @param tenantGameQuota 租户游戏配额
     * @return 租户游戏配额集合
     */
     List<TenantGameQuota> selectTenantGameQuotaList(TenantGameQuota tenantGameQuota);

    /**
     * 新增租户游戏配额
     * 
     * @param tenantGameQuota 租户游戏配额
     * @return 结果
     */
     int insertTenantGameQuota(TenantGameQuota tenantGameQuota);

    /**
     * 修改租户游戏配额
     * 
     * @param tenantGameQuota 租户游戏配额
     * @return 结果
     */
     int updateTenantGameQuota(TenantGameQuota tenantGameQuota);


    /**
     * 改变余额
     *
     * @param tenantGameQuota sys游戏配额
     * @return {@link Boolean }
     */
    Boolean changeBalance(TenantGameQuota tenantGameQuota);

    /**
     * 删除租户游戏配额
     * 
     * @param id 租户游戏配额主键
     * @return 结果
     */
     int deleteTenantGameQuotaById(Long id);

    /**
     * 批量删除租户游戏配额
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteTenantGameQuotaByIds(Long[] ids);
}
